**waterfountain**

A useful tool to share with the friends who need it most

What will this do
- bad wordle algorithm that guesses random five letter words until it fails
- random name generator for a gender but always gives names for the wrong gender
- dad joke
- british-ifier (make all caps and take out like t's and stuff)
